@@ -5,12 +5,12 @@
  ************************************************************************/
 
 #include "nccl_net.h"
-#include "net_device.h"
 #include "proxy.h"
 #include <dlfcn.h>
 
 static ncclNet_v11_t* ncclNet_v11;
 static ncclCollNet_v11_t* ncclCollNet_v11;
+static ncclGin_v11_t* ncclGin_v11;
 
 ncclNet_t* getNcclNet_v11(void* lib) {
   ncclNet_v11 = (ncclNet_v11_t*)dlsym(lib, "ncclNetPlugin_v11");
@@ -29,3 +29,12 @@ ncclCollNet_t* getNcclCollNet_v11(void* lib) {
   }
   return nullptr;
 }
+
+ncclGin_t* getNcclGin_v11(void* lib) {
+  ncclGin_v11 = (ncclGin_v11_t*)dlsym(lib, "ncclGinPlugin_v11");
+  if (ncclGin_v11) {
+    INFO(NCCL_INIT|NCCL_NET, "NET/Plugin: Loaded gin plugin %s (v11)", ncclGin_v11->name);
+    return ncclGin_v11;
+  }
+  return nullptr;
+}
